@@ -1,8 +1,3 @@
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #ifndef gpsserial_h
 #define gpsserial_h
 
@@ -24,13 +19,9 @@ extern "C"
 // int32  GPS_Serial_On_NMEA(const char *port, gpsdevh **fd);
   int32  GPS_Serial_Read(gpsdevh* fd, void* ibuf, int size);
   int32  GPS_Serial_Write(gpsdevh* fd, const void* obuf, int size);
-  int32  GPS_Serial_Write_Packet(gpsdevh* fd, GPS_PPacket packet);
+  int32  GPS_Serial_Write_Packet(gpsdevh* fd, GPS_PPacket& packet);
   int32  GPS_Serial_Send_Ack(gpsdevh* fd, GPS_PPacket* tra, GPS_PPacket* rec);
   void   GPS_Serial_Error(const char* hdr, ...);
 
 
 #endif
-
-#ifdef __cplusplus
-}
-#endif
